#[non_exhaustive]#[repr(C)]pub struct BufferDescriptor {
pub data: *mut (),
pub size: i32,
}Expand description
Non-owning NPP scratch/data buffer descriptor.
data must reference memory that remains valid for the full NPP call that
consumes this descriptor. The descriptor does not own or free the pointer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: *mut ()size: i32Trait Implementations
Sourceimpl Debug for BufferDescriptor
impl Debug for BufferDescriptor
impl Eq for BufferDescriptor
Sourceimpl From<BufferDescriptor> for NppiBufferDescriptor
impl From<BufferDescriptor> for NppiBufferDescriptor
Sourcefn from(value: BufferDescriptor) -> Self
fn from(value: BufferDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl From<NppiBufferDescriptor> for BufferDescriptor
impl From<NppiBufferDescriptor> for BufferDescriptor
Sourcefn from(value: NppiBufferDescriptor) -> Self
fn from(value: NppiBufferDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl Hash for BufferDescriptor
impl Hash for BufferDescriptor
Sourceimpl Ord for BufferDescriptor
impl Ord for BufferDescriptor
Sourcefn cmp(&self, other: &BufferDescriptor) -> Ordering
fn cmp(&self, other: &BufferDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BufferDescriptor
impl PartialEq for BufferDescriptor
Sourcefn eq(&self, other: &BufferDescriptor) -> bool
fn eq(&self, other: &BufferDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BufferDescriptor
impl PartialOrd for BufferDescriptor
impl StructuralPartialEq for BufferDescriptor