HaarBuffer

Struct HaarBuffer 

#[non_exhaustive]
#[repr(C)]
pub struct HaarBuffer { pub size: i32, pub buffer: *mut i32, }
Non-owning NPP Haar buffer descriptor.

buffer must reference device memory that remains valid for the full NPP call that consumes this descriptor. The descriptor does not own or free the pointer.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
size: i32buffer: *mut i32