HaarClassifier32f

Struct HaarClassifier32f 

#[non_exhaustive]
#[repr(C)]
pub struct HaarClassifier32f { pub classifier_count: i32, pub classifiers: *mut i32, pub classifier_step: usize, pub classifier_size: Size, pub device_counter: *mut i32, }
Non-owning NPP Haar classifier descriptor.

Raw pointer fields must reference device memory that remains valid for the full NPP call that consumes this descriptor. The descriptor does not own or free those pointers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
classifier_count: i32classifiers: *mut i32classifier_step: usizeclassifier_size: Sizedevice_counter: *mut i32