#[non_exhaustive]#[repr(C)]pub struct ImageDescriptor {
pub data: *mut (),
pub step: i32,
pub size: Size,
}Expand description
Non-owning NPP image descriptor.
data must reference image memory that remains valid for the full NPP call
that consumes this descriptor. The descriptor does not own or free the
pointer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: *mut ()step: i32size: SizeTrait Implementations
Sourceimpl Debug for ImageDescriptor
impl Debug for ImageDescriptor
impl Eq for ImageDescriptor
Sourceimpl From<ImageDescriptor> for NppiImageDescriptor
impl From<ImageDescriptor> for NppiImageDescriptor
Sourcefn from(value: ImageDescriptor) -> Self
fn from(value: ImageDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl From<NppiImageDescriptor> for ImageDescriptor
impl From<NppiImageDescriptor> for ImageDescriptor
Sourcefn from(value: NppiImageDescriptor) -> Self
fn from(value: NppiImageDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ImageDescriptor
impl Hash for ImageDescriptor
Sourceimpl Ord for ImageDescriptor
impl Ord for ImageDescriptor
Sourcefn cmp(&self, other: &ImageDescriptor) -> Ordering
fn cmp(&self, other: &ImageDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ImageDescriptor
impl PartialEq for ImageDescriptor
Sourcefn eq(&self, other: &ImageDescriptor) -> bool
fn eq(&self, other: &ImageDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ImageDescriptor
impl PartialOrd for ImageDescriptor
impl StructuralPartialEq for ImageDescriptor