#[non_exhaustive]#[repr(C)]pub struct MirrorBatchDescriptor {
pub source: *const (),
pub source_step: i32,
pub destination: *mut (),
pub destination_step: i32,
}Expand description
Non-owning NPP mirror batch descriptor.
source and destination must remain valid for the full NPP call that
consumes this descriptor. The descriptor does not own or free either
pointer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: *const ()source_step: i32destination: *mut ()destination_step: i32Trait Implementations
Sourceimpl Debug for MirrorBatchDescriptor
impl Debug for MirrorBatchDescriptor
impl Eq for MirrorBatchDescriptor
Sourceimpl From<MirrorBatchDescriptor> for NppiMirrorBatchCXR
impl From<MirrorBatchDescriptor> for NppiMirrorBatchCXR
Sourcefn from(value: MirrorBatchDescriptor) -> Self
fn from(value: MirrorBatchDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl From<NppiMirrorBatchCXR> for MirrorBatchDescriptor
impl From<NppiMirrorBatchCXR> for MirrorBatchDescriptor
Sourcefn from(value: NppiMirrorBatchCXR) -> Self
fn from(value: NppiMirrorBatchCXR) -> Self
Converts to this type from the input type.
Sourceimpl Hash for MirrorBatchDescriptor
impl Hash for MirrorBatchDescriptor
Sourceimpl Ord for MirrorBatchDescriptor
impl Ord for MirrorBatchDescriptor
Sourcefn cmp(&self, other: &MirrorBatchDescriptor) -> Ordering
fn cmp(&self, other: &MirrorBatchDescriptor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MirrorBatchDescriptor
impl PartialEq for MirrorBatchDescriptor
Sourcefn eq(&self, other: &MirrorBatchDescriptor) -> bool
fn eq(&self, other: &MirrorBatchDescriptor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MirrorBatchDescriptor
impl PartialOrd for MirrorBatchDescriptor
impl StructuralPartialEq for MirrorBatchDescriptor