WarpPerspectiveBatchDescriptor

Struct WarpPerspectiveBatchDescriptor 

#[non_exhaustive]
#[repr(C)]
pub struct WarpPerspectiveBatchDescriptor { pub source: *const (), pub source_step: i32, pub destination: *mut (), pub destination_step: i32, pub coefficients: *mut f64, pub transformed_coefficients: [[f64; 3]; 3], }
Non-owning NPP perspective-warp batch descriptor.

Raw pointer fields must remain valid for the full NPP call that consumes this descriptor. The descriptor does not own or free those pointers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
source: *const ()source_step: i32destination: *mut ()destination_step: i32coefficients: *mut f64transformed_coefficients: [[f64; 3]; 3]