pub struct ImageView<'a, T, L = C1> { /* private fields */ }Implementations
Sourceimpl<'a, T, L> ImageView<'a, T, L>where
L: ChannelLayout,
impl<'a, T, L> ImageView<'a, T, L>where
L: ChannelLayout,
pub fn from_memory(memory: &'a DeviceMemory<T>, size: Size) -> Result<Self>
pub fn from_memory_with_step( memory: &'a DeviceMemory<T>, size: Size, step: i32, ) -> Result<Self>
Sourcepub unsafe fn from_raw_parts(
ptr: *const T,
size: Size,
step: i32,
) -> Result<Self>
pub unsafe fn from_raw_parts( ptr: *const T, size: Size, step: i32, ) -> Result<Self>
Safety
ptr must be non-null CUDA device memory aligned for T that remains valid for 'a.
The allocation must cover height - 1 full byte steps plus the final
ROI row of width * L::CHANNELS * size_of::<T>() bytes. step is a
byte pitch, not an element count, and must describe the actual row
spacing visible to NPP.
Errors
Returns an error if the image shape is invalid or ptr is null.
pub const fn size(&self) -> Size
pub const fn step(&self) -> i32
pub fn byte_len(&self) -> Result<usize>