#[non_exhaustive]#[repr(C)]pub struct HaarBuffer {
pub size: i32,
pub buffer: *mut i32,
}Expand description
Non-owning NPP Haar buffer descriptor.
buffer must reference device memory that remains valid for the full NPP
call that consumes this descriptor. The descriptor does not own or free the
pointer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.size: i32buffer: *mut i32Trait Implementations
Sourceimpl Debug for HaarBuffer
impl Debug for HaarBuffer
impl Eq for HaarBuffer
Sourceimpl From<HaarBuffer> for NppiHaarBuffer
impl From<HaarBuffer> for NppiHaarBuffer
Sourcefn from(value: HaarBuffer) -> Self
fn from(value: HaarBuffer) -> Self
Converts to this type from the input type.
Sourceimpl From<NppiHaarBuffer> for HaarBuffer
impl From<NppiHaarBuffer> for HaarBuffer
Sourcefn from(value: NppiHaarBuffer) -> Self
fn from(value: NppiHaarBuffer) -> Self
Converts to this type from the input type.
Sourceimpl Hash for HaarBuffer
impl Hash for HaarBuffer
Sourceimpl Ord for HaarBuffer
impl Ord for HaarBuffer
Sourcefn cmp(&self, other: &HaarBuffer) -> Ordering
fn cmp(&self, other: &HaarBuffer) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HaarBuffer
impl PartialEq for HaarBuffer
Sourcefn eq(&self, other: &HaarBuffer) -> bool
fn eq(&self, other: &HaarBuffer) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HaarBuffer
impl PartialOrd for HaarBuffer
impl StructuralPartialEq for HaarBuffer