#[non_exhaustive]#[repr(C)]pub struct HaarClassifier32f {
pub classifier_count: i32,
pub classifiers: *mut i32,
pub classifier_step: usize,
pub classifier_size: Size,
pub device_counter: *mut i32,
}Expand description
Non-owning NPP Haar classifier descriptor.
Raw pointer fields must reference device memory that remains valid for the full NPP call that consumes this descriptor. The descriptor does not own or free those pointers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.classifier_count: i32classifiers: *mut i32classifier_step: usizeclassifier_size: Sizedevice_counter: *mut i32Trait Implementations
Sourceimpl Debug for HaarClassifier32f
impl Debug for HaarClassifier32f
impl Eq for HaarClassifier32f
Sourceimpl From<HaarClassifier32f> for NppiHaarClassifier_32f
impl From<HaarClassifier32f> for NppiHaarClassifier_32f
Sourcefn from(value: HaarClassifier32f) -> Self
fn from(value: HaarClassifier32f) -> Self
Converts to this type from the input type.
Sourceimpl From<NppiHaarClassifier_32f> for HaarClassifier32f
impl From<NppiHaarClassifier_32f> for HaarClassifier32f
Sourcefn from(value: NppiHaarClassifier_32f) -> Self
fn from(value: NppiHaarClassifier_32f) -> Self
Converts to this type from the input type.
Sourceimpl Hash for HaarClassifier32f
impl Hash for HaarClassifier32f
Sourceimpl Ord for HaarClassifier32f
impl Ord for HaarClassifier32f
Sourcefn cmp(&self, other: &HaarClassifier32f) -> Ordering
fn cmp(&self, other: &HaarClassifier32f) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HaarClassifier32f
impl PartialEq for HaarClassifier32f
Sourcefn eq(&self, other: &HaarClassifier32f) -> bool
fn eq(&self, other: &HaarClassifier32f) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for HaarClassifier32f
impl PartialOrd for HaarClassifier32f
impl StructuralPartialEq for HaarClassifier32f